| enrollcast-package | R Documentation |
Projects school enrollment using the cohort survival / grade progression ratio method, implemented as a matrix projection. Works at any level of aggregation and any number of grades. Provides functions to compute progression ratios from historical grade-level enrollment and to project future enrollment forward an arbitrary horizon.
Maintainer: Rory Lawless rory@rorylawless.com (ORCID) [copyright holder]
Authors:
Rory Lawless rory@rorylawless.com (ORCID) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.